@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -21,6 +21,8 @@ else:
 
 __all__ = (
     "ArchitectureType",
+    "ComputeTypeType",
+    "DataSourceTypeType",
     "DeploymentJobErrorCodeType",
     "DeploymentStatusType",
     "ExitBehaviorType",
@@ -57,6 +59,8 @@ __all__ = (
 
 
 ArchitectureType = Literal["ARM64", "ARMHF", "X86_64"]
+ComputeTypeType = Literal["CPU", "GPU_AND_CPU"]
+DataSourceTypeType = Literal["Archive", "File", "Prefix"]
 DeploymentJobErrorCodeType = Literal[
     "BadLambdaAssociated",
     "BadPermissionError",
@@ -109,7 +113,7 @@ RobotDeploymentStepType = Literal[
     "Launching",
     "Validating",
 ]
-RobotSoftwareSuiteTypeType = Literal["ROS", "ROS2"]
+RobotSoftwareSuiteTypeType = Literal["General", "ROS", "ROS2"]
 RobotSoftwareSuiteVersionTypeType = Literal["Dashing", "Foxy", "Kinetic", "Melodic"]
 RobotStatusType = Literal[
     "Available", "Deploying", "Failed", "InSync", "NoResponse", "PendingNewDeployment", "Registered"
@@ -171,7 +175,7 @@ SimulationJobStatusType = Literal[
     "Terminated",
     "Terminating",
 ]
-SimulationSoftwareSuiteTypeType = Literal["Gazebo", "RosbagPlay"]
+SimulationSoftwareSuiteTypeType = Literal["Gazebo", "RosbagPlay", "SimulationRuntime"]
 UploadBehaviorType = Literal["UPLOAD_ON_TERMINATE", "UPLOAD_ROLLING_AUTO_REMOVE"]
 WorldExportJobErrorCodeType = Literal[
     "AccessDenied",
@@ -394,6 +398,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
